******
Mopidy
******

Mopidy is a music server which can play music from `Spotify
<http://www.spotify.com/>`_ or from your local hard drive. To search for music
in Spotify's vast archive, manage playlists, and play music, you can use most
`MPD clients <http://mpd.wikia.com/>`_. MPD clients are available for most
platforms, including Windows, Mac OS X, Linux, Android, and iOS.

To install Mopidy, start out by reading :ref:`installation`.

If you get stuck, we usually hang around at ``#mopidy`` at `irc.freenode.net
<http://freenode.net/>`_. If you stumble into a bug or got a feature request,
please create an issue in the `issue tracker
<http://github.com/mopidy/mopidy/issues>`_.


Project resources
=================

- `Documentation <http://docs.mopidy.com/>`_
- `Source code <http://github.com/mopidy/mopidy>`_
- `Issue tracker <http://github.com/mopidy/mopidy/issues>`_
- IRC: ``#mopidy`` at `irc.freenode.net <http://freenode.net/>`_


User documentation
==================

.. toctree::
    :maxdepth: 3

    installation/index
    settings
    running
    clients/index
    authors
    licenses
    changes

Reference documentation
=======================

.. toctree::
    :maxdepth: 3

    api/index
    modules/index

Development documentation
=========================

.. toctree::
    :maxdepth: 3

    development/index

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

